@@ -68,7 +68,7 @@ class iexCommon():
 
     def __init__(self, endpoint, symbol, external=False):
         self.url = f'iexapis.com/stable/{section}/{symbol}/{endpoint}?'
-        if external not False:
+        if not external == False:
             self.token = external
             self.parse_token_sandbox(self.token)
         else:
